@@ -1,5 +1,5 @@
 from boxsdk import JWTAuth, Client
-from adp_connectors.base import Connector
+from .base import Connector
 
 
 class BoxConnector(Connector):
