@@ -1,6 +1,6 @@
 import json
 import boto3
-from adp_connectors.base import Connector
+from .base import Connector
 
 
 class S3Connector(Connector):
